
function [] = fit_ringdown_top_dualLaser_bluecalib(cooling_est_boolean);
    % Top level script for fitting ringdown measurements. Run from directory
    % containing data folders (prefix 'fit').

   
    f_mechanical = 5.3124555e9;
    gammaSB0_nc1 = 31.4; % c.p.s.
    
    g0 = 7.5e5; % Hz
    kappa = 5.55e8; % Hz
    gammaOMperphoton = 4*g0^2/kappa;
    
    %cooling_est_boolean = 1;
    Trpulse = 20e-6; % sec
    
  

    save_directory_prefix = ['PLOT_combinedmegaRingdown_02192018'];
    savedir_num = 0;
    save_directory = [save_directory_prefix '_' num2str(savedir_num)];
    while (exist(save_directory,'dir')==7)
        savedir_num = savedir_num + 1;
        save_directory = [save_directory_prefix '_' num2str(savedir_num)];
    end
    mkdir(save_directory);

    dataPath = pwd;
    saveFits = 1;
    clear ds

    nameTag = ['DualPulse_megaRingdown'];

    dirInfo = dir([nameTag '*']);

    ds.nRatios = [];
    ds.nRatioErr = [];
    ds.Qests = [];
    ds.Tpers = [];
    ds.Toffs = [];
    ssCRs = [];
    ds.gammatotal = [];
    ds.gammaS = [];
    ds.deltab = [];
    ds.relErrs = [];
    ds.CRs = [];
    ds.blueCR = [];
    ds.bluenbar = [];
    ds.decayratio = [];
    ds.blueCts = [];
    ds.redCts = [];
    % check that each is a directory, then go into that directory
    j = 0;
    for k = 1:length(dirInfo)

        if dirInfo(k).isdir
            j = j + 1;
            dirName = dirInfo(j).name;
            pulseFreq = sscanf(dirName(strfind(dirName,'PulseF_'):end),'PulseF_%fHz%*s');
            %pulseLen = 1e-6*sscanf(dirName(strfind(dirName,'Tpulse_'):end),'Tpulse_%fus%*s');
            ds.Toffs(j) = 1e-6*sscanf(dirName(strfind(dirName,'Toff_'):end),'Toff_%fus%*s');
            Attread = sscanf(dirName(strfind(dirName,'read_'):end),'read_%fdB%*s');
            AttreadBlue = sscanf(dirName(strfind(dirName,'blueL2_'):end),'blueL2_%fdB%*s');
            
            ncread = att2nc(Attread);
            ncblue = att2nc_arc(AttreadBlue);
            
            gammaSB0_ncAtt = gammaSB0_nc1*ncread;
            gammaSB0_ncAttBlue = gammaSB0_nc1*ncblue;
            
            % go into that folder
            cd([dataPath '\' dirInfo(j).name]);

            % determine number of chunks
            datInfo = dir('PHcounts*.mat');
            numChunks = length(datInfo);
            if numChunks>0
                fn1 = datInfo(1).name;
                intTime = sscanf(fn1(strfind(fn1,'intTime_'):end),'intTime_%fsec%*s');

                % combine data chunks
                cd(dataPath);
                [totredCts CR relErr countsArr]  = combine_ph_datasets_fit_dualLaser(dataPath, dirName, numChunks, intTime, pulseFreq);
                nbarArr = countsArr./(gammaSB0_ncAtt);
                ds.nbar(j) = CR/gammaSB0_ncAtt;
                ds.redCts(j) = totredCts;
                ds.CRs(j) = CR;
                ds.relErrs(j) = relErr;
                
                
                [totcts blueCR relErr countsArr]  = combine_ph_datasets_fit_dualLaser_bluepulse(dataPath, dirName, numChunks, intTime, pulseFreq);
                ds.blueCR(j) = blueCR;
                ds.bluenbar(j) = blueCR/gammaSB0_ncAttBlue;
                ds.blueCts(j) = totcts;

                ds.decayratio(j) = ds.nbar(j)/ds.bluenbar(j);
                            
                cd([dataPath '\' save_directory]);
                save(['nbarArr_Toff_' num2str(ds.Toffs(j)*1e3) 'ms.mat'],'nbarArr');
                cd(dataPath);
                close;
                
                
                if cooling_est_boolean
                    % calculate cooling rate
                    gammaOMradpersec = 2*pi*gammaOMperphoton*ncread;
                    % calculate cooling factor
                    coolingFactor = exp(-gammaOMradpersec*Trpulse/2);
                    ds.nbar(j) = ds.nbar(j)/coolingFactor;
                    ds.decayratio(j) = ds.nbar(j)/ds.bluenbar(j);
                end
                
                
            else
                cd(dataPath);
                ds.nbar(j) = ds.nbar(j-1);
                ds.relErrs(j) = 0;
            end

        end   

    end

    cd([dataPath '\' save_directory]);
    save('dataInfo.mat','ds');
    cd(dataPath);
    
%     
%     M = length(unique(ds.Toffs)); % number of Toff values
%     ToffsArr = [];
%     numident = 7;
%     meandecay = [];
%     meannbarerrs = [];
%     meandecayerrs = [];
%     blueCRavg = [];
%     bluectsavg = [];
%     meannbars = [];
%     redctsavg = [];
%     for m = 1:M
%         decayindices = [numident*(m-1)+1:numident*(m-1)+numident];
%         ToffsArr(m) = ds.Toffs(numident*(m-1)+1);
%         meandecay(m) = mean(ds.decayratio(decayindices));
%         meannbarerrs(m) = std(ds.nbar(decayindices));
%         blueCRavg(m) = mean(ds.blueCR(decayindices));
%         meannbars(m) = mean(ds.nbar(decayindices));
%         bluectsavg(m) = mean(ds.blueCts(decayindices));
%         redctsavg(m) = mean(ds.redCts(decayindices));
%         meandecayerrs(m) = std(ds.decayratio(decayindices));
%     end
%
    

    ToffsArr = [];
    meanDecay = [];
    meanNbarErrs = [];
    meanDecayErrs = [];
    blueCRavg = [];
    blueCtsAvg = [];
    meanNbars = [];
    redctsavg = [];

    NN = length(ds.Toffs);
    [sortedToffs ind] = sort(ds.Toffs);
    groupEndIndices = find(diff(sortedToffs)~=0);
    M = length(groupEndIndices);
    
    for m = 1:M+1
        % for each group of Toff values
        
        if m == 1
            sortedinds = 1:groupEndIndices(m);
        elseif m == M+1
            sortedinds = groupEndIndices(end)+1:NN;
        else
            sortedinds = groupEndIndices(m-1)+1:groupEndIndices(m);
        end
       
        unsortedinds = ind(sortedinds);
       
        ToffsArr(m) = ds.Toffs(unsortedinds(1));
        meanDecay(m) = mean(ds.decayratio(unsortedinds));
        meanNbarErrs(m) = std(ds.nbar(unsortedinds));
        blueCRavg(m) = mean(ds.blueCR(unsortedinds));
        meanNbars(m) = mean(ds.nbar(unsortedinds));
        blueCtsAvg(m) = mean(ds.blueCts(unsortedinds));
        redctsavg(m) = mean(ds.redCts(unsortedinds));
        meanDecayErrs(m) = std(ds.decayratio(unsortedinds));
       
    end


    
    figure();
    scatter(ToffsArr, redctsavg);
    xlabel('T_{off} (s)'); ylabel('averaged red cts');
    set(gca,'YScale','log');

    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['AvgRedCts_vs_Toff.fig']);
    
  
    figure();
    scatter(ToffsArr, blueCtsAvg);
    xlabel('T_{off} (s)'); ylabel('averaged blue cts');
    set(gca,'YScale','log');

    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['AvgBlueCts_vs_Toff.fig']);
     
    
    
    
     
    
    
    figure();
    scatter(ToffsArr, meanNbars);
    xlabel('T_{off} (s)'); ylabel('averaged <n>');
    set(gca,'YScale','log');

    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['AvgNbar_vs_Toff.fig']);
     
     
    
    figure();
    scatter(ToffsArr, blueCRavg);
    xlabel('T_{off} (s)'); ylabel('averaged blue CR');
    set(gca,'YScale','log');

    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['AVgblueCR_vs_Toff.fig']);
    
    
    
    figure;
    scatter(ds.Toffs,ds.blueCts,'bo','MarkerFaceColor','b');
    %ylim([0.9*min(ds.nbar) 1.1*max(ds.nbar)]);
    xlabel('T_{off} (s)'); ylabel('Blue total cts');
    title('Ringdown curve');
    set(gca,'YScale','log');
    set(gca,'XScale','lin');
    saveas(gcf,['BlueCts_vs_Toff.fig']); 
    
    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['nbar_vs_Toff.fig']);
    
    
    
    figure;
    scatter(ds.Toffs,ds.redCts,'bo','MarkerFaceColor','b');
    %ylim([0.9*min(ds.nbar) 1.1*max(ds.nbar)]);
    xlabel('T_{off} (s)'); ylabel('Red total cts');
    title('Ringdown curve');
    set(gca,'YScale','log');
    set(gca,'XScale','lin');
    saveas(gcf,['RedCts_vs_Toff.fig']); 
    
    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['nbar_vs_Toff.fig']);
    
    
   
    %Plot blueCR of each chunk.
    figure;
    scatter(ds.Toffs,ds.nbar,'bo','MarkerFaceColor','b');
    %ylim([0.9*min(ds.nbar) 1.1*max(ds.nbar)]);
    xlabel('T_{off} (s)'); ylabel('<n>');
    title('Ringdown curve');
    set(gca,'YScale','log');
    set(gca,'XScale','lin');
    saveas(gcf,['BlueCR_vs_Toff.fig']); 
    
    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['nbar_vs_Toff.fig']);
     
    
    
    %Plot blueCR of each chunk.
    figure;
    scatter(ds.Toffs,ds.blueCR,'bo','MarkerFaceColor','b');
    %ylim([0.9*min(ds.nbar) 1.1*max(ds.nbar)]);
    xlabel('T_{off} (s)'); ylabel('Blue CR');
    title('Ringdown curve');
    set(gca,'YScale','log');
    set(gca,'XScale','lin');
    saveas(gcf,['BlueCR_vs_Toff.fig']);

    % Plot nRatio results
    %ratioErrs = ds.nbar.*ds.relErrs;
    figure;
    scatter(ds.Toffs,ds.decayratio,'bo','MarkerFaceColor','b');

    %xlim([0 1.2*max(ds.Toffs)]);
    %ylim([0.9*min(ds.nbar) 1.1*max(ds.nbar)]);
    xlabel('T_{off} (s)'); ylabel('Decay ratio');
    title('Ringdown curve');
    set(gca,'YScale','log');
    set(gca,'XScale','lin');
    


    cd([dataPath '\' save_directory]);
    saveas(gcf,['DecayRatio_vs_Toff.fig']);
    
    % fit exponential
    
    
    
    
    figure();
    scatter(ToffsArr, meanDecay);
    xlabel('T_{off} (s)'); ylabel('averaged decay ratio');
    set(gca,'YScale','log');

    
    cd([dataPath '\' save_directory]);
    saveas(gcf,['AvgDecayRatio_vs_Toff.fig']);
    
    
    
    
    Toffs = ToffsArr;%ds.Toffs;
    %decayratios = ds.decayratio;
    decayratios = meanDecay;
    
    % get region to fit
    [ToffBds CRbds] = ginput(2);
    %find Toff values and nRatios in range
    ToffBds = ToffBds;
    fitIndices = find(Toffs>min(ToffBds) & Toffs<max(ToffBds));
    fitToffs = Toffs(fitIndices);
    Toff_offset = 0;%min(fitToffs);
    fitToffs = fitToffs - Toff_offset;
    fitnRatios = decayratios(fitIndices);
    
    tArr = [0 logspace(log10(0.5*min(Toffs(fitIndices))),log10(max(Toffs(fitIndices))),1e4)];%[0 logspace(log10(0.9*min(Toffs(fitIndices))),log10(max(Toffs(fitIndices))),1e4)];

    
    
% === DECAYS TO A CONSTANT OFFSET VALUE ===================================
%     GammaFitCurve = @(x,fitToffs)(x(2) + x(3)*exp(-x(1)*fitToffs));
%     gammaGuess = 1/(max(fitToffs) - min(fitToffs));
%     x0 = [gammaGuess min(fitnRatios) max(fitnRatios)];
% 
%     initialCurve = (x0(2) + x0(3)*exp(-x0(1)*tArr));
%     fitParams = lsqcurvefit(GammaFitCurve,x0,fitToffs,fitnRatios,[0 0 0],[1e6 50 100]);
%     gammaTotal_in_radians = fitParams(1);
%     Q_final = f_mechanical/(gammaTotal_in_radians/2/pi);
%     fitCurve = GammaFitCurve(fitParams, tArr);
%%%% ======================================================================


% === DECAYS TO ZERO ======================================================
    GammaFitCurve = @(x,fitToffs)(x(2)*exp(-x(1)*fitToffs));
    gammaGuess = 1/(max(fitToffs) - min(fitToffs));
    x0 = [gammaGuess max(fitnRatios)];

    initialCurve = (x0(2)*exp(-x0(1)*tArr));
    [fitParams, resnorm, resid, exitflag, output, lambda, J] = lsqcurvefit(GammaFitCurve,x0,fitToffs,fitnRatios,[0 0],[1e6 100]);
    alpha = 0.1;
    ci = nlparci(fitParams, resid, 'jacobian',J,'alpha',alpha);
    gammaTotal_in_radians = fitParams(1);
    Q_final = f_mechanical/(gammaTotal_in_radians/(2*pi));
    Q_final_upperBd = f_mechanical/((ci(1,1))/(2*pi));
    Q_final_lowerBd = f_mechanical/((ci(1,2))/(2*pi));
    
    
    
    fitCurve = GammaFitCurve(fitParams, tArr);
    fitCurveLowerBd = GammaFitCurve([ci(1,1) fitParams(2)], tArr);
    fitCurveUpperBd = GammaFitCurve([ci(1,2) fitParams(2)], tArr);
% =========================================================================
    
    
    figure();
    errorbar(ToffsArr, meanDecay, meanDecayErrs, 'bo','MarkerFaceColor','b');
    xlabel('T_{off} (s)'); ylabel('averaged decay ratio');
    set(gca,'YScale','log');

    
    
    
    hold on
    plot(tArr+Toff_offset,fitCurve,'r','LineWidth',2);
    plot(tArr+Toff_offset,fitCurveLowerBd,'k','LineWidth',0.5);
    plot(tArr+Toff_offset,fitCurveUpperBd,'b','LineWidth',0.5);
    set(gca,'YScale','log');

    title(['Ringdown curve | Fitted Q = ' num2str(Q_final/1e9) '\times10^9, 90% Conf. Int. [' num2str(round(Q_final_lowerBd/1e9*10)/10) ', ' num2str(round(Q_final_upperBd/1e9*10)/10) ']\times10^9']);
    %legend('Data',['Q = ' num2str(Q_final/1e9) '\times 10^9'],['Q = ' num2str(Q_final_upperBd/1e9) '\times 10^9'],['Q = ' num2str(Q_final_lowerBd/1e9) '\times 10^9']);
    hold off
    saveas(gcf,['Fitted_gamma_' round(num2str(gammaTotal_in_radians/2/pi)) 'Hz.fig']);
    
    
    
    
    
    
    
    a = fitParams(2);
    
    figure();
    errorbar(ToffsArr, meanDecay/a, meanDecayErrs/a, 'bo','MarkerFaceColor','b');
    xlabel('T_{off} (s)'); ylabel('normalized decay ratio');
    set(gca,'YScale','log');
    ylim([0.8*min((meanDecay-meanDecayErrs)/a) 1.2*max((meanDecay+meanDecayErrs)/a)]);
    
    hold on
    plot(tArr+Toff_offset,fitCurve/a,'r','LineWidth',2);
    plot(tArr+Toff_offset,fitCurveLowerBd/a,'k','LineWidth',0.5);
    plot(tArr+Toff_offset,fitCurveUpperBd/a,'b','LineWidth',0.5);
    set(gca,'YScale','log');

    title(['Ringdown curve | Fitted Q = ' num2str(Q_final/1e9) '\times10^9, 90% Conf. Int. [' num2str(round(Q_final_lowerBd/1e9*10)/10) ', ' num2str(round(Q_final_upperBd/1e9*10)/10) ']\times10^9']);
    %legend('Data',['Q = ' num2str(Q_final/1e9) '\times 10^9'],['Q = ' num2str(Q_final_upperBd/1e9) '\times 10^9'],['Q = ' num2str(Q_final_lowerBd/1e9) '\times 10^9']);
    hold off
    saveas(gcf,['Fitted_normalized_DR_Q' round(num2str(Q_final/1e9)) 'e9.fig']);
    
    

%     figure();
%     scatter(ds.Toffs,ds.gammatotal);
%     ylabel('gammaTotal (radHz)'); xlabel('Toff');
%     saveas(gcf,'gammaTotalFitted.fig');
%     
%     figure();
%     scatter(ds.Toffs,ds.gammaS);
%     ylabel('gammaS (radHz)'); xlabel('Toff');
%     saveas(gcf,'gammaSFitted.fig');
%     
%     figure();
%     scatter(ds.Toffs,ds.deltab);
%     ylabel('SBF'); xlabel('Toff');
%     saveas(gcf,'deltabFitted');
    
    cd(dataPath);
    
    % end
end

%%% HELPER FUCNTIONS %%%

function [totredcts CR relErr countsArr] = combine_ph_datasets_fit_dualLaser(topDirectory,dataDirectory,N,Tint,f_pulse)

    % dataset parameters and calibrations
    
    Tper = 1/f_pulse;
    numChannels = 65536;
    postbin = 20;
    allCounts = zeros(numChannels, N);
    tbin = 0.512*(1:numChannels);
    thresh = 0.90; % discard any chunks with transmission below thresh compared to avg
    badSets = filter3_reject_datasets(thresh);

    numGoodSets = 0;
    cd(dataDirectory);
    for k = 1:N
        if ~ismember(k,badSets)
            numGoodSets = numGoodSets + 1;
            filename = sprintf(['PHcounts_intTime_' num2str(Tint) 'sec_fileNum%i_segment_1.mat'], k);
            allCounts(:,k) = importdata(filename);
        end
    end
    cd(topDirectory);

    totCounts = sum(allCounts, 2);

    if postbin > 1
        pb_counts = [];
        pb_t = [];
        for k = 1:length(totCounts)/postbin
            pb_counts(end+1) = sum(totCounts((k-1)*postbin+1:k*postbin));
            pb_t(end+1) = (k-1)*512e-12*postbin;
        end
    end

    tbinsize = 512e-12*postbin;
    countsArr = pb_counts.*Tper/(tbinsize*Tint*numGoodSets);
    
    startBin = 562; % red pulse
    endBin = 2448;
    CR = mean(countsArr(startBin:endBin));
    relErr = 1/sqrt(sum(pb_counts(startBin:endBin)));
    totredcts = sum(pb_counts(startBin:endBin));
    
    
end



function [totcts CR relErr countsArr] = combine_ph_datasets_fit_dualLaser_bluepulse(topDirectory,dataDirectory,N,Tint,f_pulse)

    % dataset parameters and calibrations
    
    Tper = 1/f_pulse;
    numChannels = 65536;
    postbin = 20;
    allCounts = zeros(numChannels, N);
    tbin = 0.512*(1:numChannels);
    thresh = 0.90; % discard any chunks with transmission below thresh compared to avg
    badSets = filter3_reject_datasets(thresh);

    numGoodSets = 0;
    cd(dataDirectory);
    for k = 1:N
        if ~ismember(k,badSets)
            numGoodSets = numGoodSets + 1;
            filename = sprintf(['blueCal_PHcounts_intTime_' num2str(Tint) 'sec_fileNum%i_segment_1.mat'], k);
            allCounts(:,k) = importdata(filename);
        end
    end
    cd(topDirectory);

    totCounts = sum(allCounts, 2);

    if postbin > 1
        pb_counts = [];
        pb_t = [];
        for k = 1:length(totCounts)/postbin
            pb_counts(end+1) = sum(totCounts((k-1)*postbin+1:k*postbin));
            pb_t(end+1) = (k-1)*512e-12*postbin;
        end
    end

    tbinsize = 512e-12*postbin;
    countsArr = pb_counts.*Tper/(tbinsize*Tint*numGoodSets);
    
    startBin = 1; % red pulse
    endBin = 2838;
    CR = mean(countsArr(startBin:endBin));
    relErr = 1/sqrt(sum(pb_counts(startBin:endBin)));
    totcts = sum(pb_counts(startBin:endBin));
    
    
    
end



function [tArr, fitCurve, initialPoint, initialPtMin, initialPtMax, finalPoint, x] = fitHeatingModelTop(nbarBuffer,binsize,plotbacknum)

    % Fit pulse-on data
    
    % === define fitting data
    tArr0 = linspace(0,binsize*length(nbarBuffer),length(nbarBuffer)+1);
    tArr0 = tArr0(1:end-1);
    dataArr = nbarBuffer;
    
    % === fit parameter guesses
    gammatot = 6e6; % x0(1)
    gammas = 5e5; % x0(2)
    deltab = 0.75; % x0(3)
    ni = dataArr(1); % x0(4)
    nf = mean(dataArr(end-10:end)); % x0(5)
    
    % pulse-on fitting function (PRX2015 S.I. for ref) with fast and slow bath turn-on
    fitFun = @(x,xdata) x(4)*exp(-x(1)*xdata) + x(5)*(1-exp(-x(1)*xdata)) + x(3)*x(5)*(x(1)/(x(2)-x(1)))*(exp(-x(2)*xdata) - exp(-x(1)*xdata));

    % initialize fit parameter guesses
    x0 = [gammatot, gammas, deltab, ni, nf];
    initialCurve = fitFun(x0, tArr0);
    
    % fitting
    [x, resnorm, resid, exitflag, output, lambda, J] = lsqcurvefit(fitFun,x0,tArr0,dataArr,[0, 0, 0, 0, 0]);
    
    % back-extrapolate fit curve by half a bin width to initial point
    offset = (0)*binsize; % how far to back-extrapolate fit from first "fully on" point
    plotdist = fliplr(-binsize:-binsize:-plotbacknum*binsize); % from true pulse start to first "fully on" point taken
    initialPoint = fitFun(x, offset);
    finalPoint = fitFun(x, max(tArr0));
       
    tArr = [plotdist tArr0];
    fitCurve = fitFun(x, tArr);
    
    % calculate error
    alpha = 0.1; % 90% confidence interval
    ci = nlparci(x,resid,'jacobian',J,'alpha',alpha);
    nimin = ci(4,1);
    nimax = ci(4,2);
    xparamsmin = [x(1), x(2), x(3), x(4)+nimin, x(5)];
    xparamsmax = [x(1), x(2), x(3), x(4)+nimax, x(5)];
    initialPtMin = fitFun(xparamsmin, offset);
    initialPtMax = fitFun(xparamsmax, offset);
    
    % plot fitting result
    figure();
    hold on;
    plot(tArr0,dataArr);
    plot(tArr,fitCurve,'r');
    hold off;
    xlabel('Time in pulse (s)');
    ylabel('n');
    close();
    
end


function badSets = filter3_reject_datasets(thresh);

endInfo = dir('filter3_DAQV_End_*.txt');
startInfo = dir('filter3_DAQV_Initial_*.txt');

% sort endInfo
NumArr = [];
for k = 1:length(endInfo)
    fn = endInfo(k).name;
    NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
end

indexArray = [NumArr', [1:length(endInfo)]'];
[values order] = sort(indexArray(:,1));

f3_end_voltagelog = []; f3_start_voltagelog = [];
for k = 1:length(endInfo)
    fn = endInfo(order(k)).name;
    f3_end_voltagelog = [f3_end_voltagelog load(endInfo(k).name)];
end

% sort startInfo
clear NumArr;
NumArr = [];
for k = 1:length(startInfo)
    fn = startInfo(k).name;
    NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
end

indexArray = [NumArr', [1:length(startInfo)]'];
[values order] = sort(indexArray(:,1));


for k = 1:length(startInfo)
    fn = startInfo(order(k)).name;
    f3_start_voltagelog = [f3_start_voltagelog load(startInfo(k).name)];
end

f3_end_voltagelog = f3_end_voltagelog(2:end);
f3_start_voltagelog = f3_start_voltagelog(1:end-1);


ds = f3_end_voltagelog./f3_start_voltagelog;

badSets = find(ds < thresh | ds > 1.5);
length(badSets);
%plot(ds); xlabel('file index'); ylabel('Filter 3 DAQ voltage');

end



function [Q] = estQcrude(ratio,Tper)

gamma = -log(ratio)/Tper;
Q = 2*pi*10e9/gamma;

end
