
function [] = fit_ringdown_top_dualLaser_fixattLongpulse();
    % Top level script for fitting ringdown measurements. Run from directory
    % containing data folders (prefix 'fit').

    bleed_through_CR = 15; % c.p.s., independently calibrated
    f_mechanical = 5.3124555e9;
    gammaSB0_nc1 = 31.4; % c.p.s.
%     gammaSB0_ncAtt = 59.4*att2nc(27);%gammaSB0est(0.1);

    save_directory_prefix = ['PLOT_ringdown_02162018'];
    savedir_num = 0;
    save_directory = [save_directory_prefix '_' num2str(savedir_num)];
    while (exist(save_directory,'dir')==7)
        savedir_num = savedir_num + 1;
        save_directory = [save_directory_prefix '_' num2str(savedir_num)];
    end
    mkdir(save_directory);

    dataPath = pwd;
    saveFits = 1;
    clear ds

    nameTag = ['DualPulse_megaRingdown8'];

    dirInfo = dir([nameTag '*']);

    ds.nRatios = [];
    ds.nRatioErr = [];
    ds.Qests = [];
    ds.Tpers = [];
    ds.Toffs = [];
    ssCRs = [];
    ds.gammatotal = [];
    ds.gammaS = [];
    ds.deltab = [];
    ds.relErrs = [];
    ds.CRs = [];
    % check that each is a directory, then go into that directory
    j = 0;
    for k = 1:length(dirInfo)

        if dirInfo(k).isdir
            j = j + 1;
            dirName = dirInfo(j).name;
            pulseFreq = sscanf(dirName(strfind(dirName,'PulseF_'):end),'PulseF_%fHz%*s');
            %pulseLen = 1e-6*sscanf(dirName(strfind(dirName,'Tpulse_'):end),'Tpulse_%fus%*s');
            ds.Toffs(j) = 1e-6*sscanf(dirName(strfind(dirName,'Toff_'):end),'Toff_%fus%*s');
            Attread = sscanf(dirName(strfind(dirName,'read_'):end),'read_%fdB%*s');
            
            gammaSB0_ncAtt = gammaSB0_nc1*att2nc(Attread);%gammaSB0est(0.1);

            % go into that folder
            cd([dataPath '\' dirInfo(j).name]);

            % determine number of chunks
            datInfo = dir('PHcounts*.mat');
            numChunks = length(datInfo);
            if numChunks>0
                fn1 = datInfo(1).name;
                intTime = sscanf(fn1(strfind(fn1,'intTime_'):end),'intTime_%fsec%*s');

                % combine data chunks
                cd(dataPath);
                [CR relErr countsArr]  = combine_ph_datasets_fit_dualLaser(dataPath, dirName, numChunks, intTime, pulseFreq);
                nbarArr = countsArr./(gammaSB0_ncAtt);
                ds.nbar(j) = CR/gammaSB0_ncAtt;
                ds.CRs(j) = CR;
                ds.relErrs(j) = relErr;



                cd([dataPath '\' save_directory]);
                save(['nbarArr_Toff_' num2str(ds.Toffs(j)*1e3) 'ms.mat'],'nbarArr');
                cd(dataPath);
                close;
            else
                cd(dataPath);
                ds.nbar(j) = ds.nbar(j-1);
                ds.relErrs(j) = 0;
            end

        end   

    end

    cd([dataPath '\' save_directory]);
    save('dataInfo.mat','ds');
    cd(dataPath);

    % Plot nRatio results
    nbarErrs = ds.nbar.*ds.relErrs;
    errorbar(ds.Toffs,ds.nbar,nbarErrs,'bo','MarkerFaceColor','b');

    xlim([0 1.2*max(ds.Toffs)]);
    ylim([0.9*min(ds.nbar) 1.1*max(ds.nbar)]);
    xlabel('T_{off} (s)'); ylabel('<n>');
    title('Ringdown curve');
    %set(gca,'YScale','log');
    set(gca,'XScale','lin');

    cd([dataPath '\' save_directory]);
    saveas(gcf,['Occupancy_vs_Toff.fig']);
    
    % fit exponential
    
    Toffs = ds.Toffs;
    nbar = ds.nbar/max(ds.nbar);
    
    % get region to fit
    [ToffBds CRbds] = ginput(2);
    %find Toff values and nRatios in range
    ToffBds = ToffBds;
    fitIndices = find(Toffs>min(ToffBds) & Toffs<max(ToffBds));
    fitToffs = Toffs(fitIndices);
    Toff_offset = 0%min(fitToffs);
    fitToffs = fitToffs - Toff_offset;
    fitnRatios = nbar(fitIndices);
    
    tArr = [0 logspace(log10(0.5*min(Toffs(fitIndices))),log10(max(Toffs(fitIndices))),1e4)];%[0 logspace(log10(0.9*min(Toffs(fitIndices))),log10(max(Toffs(fitIndices))),1e4)];

    
    
% === DECAYS TO A CONSTANT OFFSET VALUE ===================================
%     GammaFitCurve = @(x,fitToffs)(x(2) + x(3)*exp(-x(1)*fitToffs));
%     gammaGuess = 1/(max(fitToffs) - min(fitToffs));
%     x0 = [gammaGuess min(fitnRatios) max(fitnRatios)];
% 
%     initialCurve = (x0(2) + x0(3)*exp(-x0(1)*tArr));
%     fitParams = lsqcurvefit(GammaFitCurve,x0,fitToffs,fitnRatios,[0 0 0],[1e6 50 100]);
%     gammaTotal_in_radians = fitParams(1);
%     Q_final = f_mechanical/(gammaTotal_in_radians/2/pi);
%     fitCurve = GammaFitCurve(fitParams, tArr);
%%%% ======================================================================


% === DECAYS TO ZERO ======================================================
    GammaFitCurve = @(x,fitToffs)(x(2)*exp(-x(1)*fitToffs));
    gammaGuess = 1/(max(fitToffs) - min(fitToffs));
    x0 = [gammaGuess max(fitnRatios)];

    initialCurve = (x0(2)*exp(-x0(1)*tArr));
    fitParams = lsqcurvefit(GammaFitCurve,x0,fitToffs,fitnRatios,[0 0],[1e6 100]);
    gammaTotal_in_radians = fitParams(1);
    Q_final = f_mechanical/(gammaTotal_in_radians/2/pi);
    fitCurve = GammaFitCurve(fitParams, tArr);
% =========================================================================
    
    
    
    hold on
    plot(tArr+Toff_offset,fitCurve*max(ds.nbar),'r','LineWidth',2);
    set(gca,'YScale','log');

    title(['Ringdown curve | Fitted Q = ' num2str(Q_final/1e9) '\times 10^9']);
    hold off
    saveas(gcf,['Fitted_gamma_' round(num2str(gammaTotal_in_radians/2/pi)) 'Hz.fig']);

%     figure();
%     scatter(ds.Toffs,ds.gammatotal);
%     ylabel('gammaTotal (radHz)'); xlabel('Toff');
%     saveas(gcf,'gammaTotalFitted.fig');
%     
%     figure();
%     scatter(ds.Toffs,ds.gammaS);
%     ylabel('gammaS (radHz)'); xlabel('Toff');
%     saveas(gcf,'gammaSFitted.fig');
%     
%     figure();
%     scatter(ds.Toffs,ds.deltab);
%     ylabel('SBF'); xlabel('Toff');
%     saveas(gcf,'deltabFitted');
    
    cd(dataPath);
    
    % end
end

%%% HELPER FUCNTIONS %%%

function [CR relErr countsArr] = combine_ph_datasets_fit_dualLaser(topDirectory,dataDirectory,N,Tint,f_pulse)

    % dataset parameters and calibrations
    
    Tper = 1/f_pulse;
    numChannels = 65536;
    postbin = 20;
    allCounts = zeros(numChannels, N);
    tbin = 0.512*(1:numChannels);
    thresh = 0.90; % discard any chunks with transmission below thresh compared to avg
    badSets = filter3_reject_datasets(thresh);

    numGoodSets = 0;
    cd(dataDirectory);
    for k = 1:N
        if ~ismember(k,badSets)
            numGoodSets = numGoodSets + 1;
            filename = sprintf(['PHcounts_intTime_' num2str(Tint) 'sec_fileNum%i_segment_1.mat'], k);
            allCounts(:,k) = importdata(filename);
        end
    end
    cd(topDirectory);

    totCounts = sum(allCounts, 2);

    if postbin > 1
        pb_counts = [];
        pb_t = [];
        for k = 1:length(totCounts)/postbin
            pb_counts(end+1) = sum(totCounts((k-1)*postbin+1:k*postbin));
            pb_t(end+1) = (k-1)*512e-12*postbin;
        end
    end

    tbinsize = 512e-12*postbin;
    countsArr = pb_counts.*Tper/(tbinsize*Tint*numGoodSets);
    
    startBin = 562; % red pulse
    endBin = 2448;
    CR = mean(countsArr(startBin:endBin));
    relErr = 1/sqrt(sum(pb_counts(startBin:endBin)));
    
    
    
end


function [tArr, fitCurve, initialPoint, initialPtMin, initialPtMax, finalPoint, x] = fitHeatingModelTop(nbarBuffer,binsize,plotbacknum)

    % Fit pulse-on data
    
    % === define fitting data
    tArr0 = linspace(0,binsize*length(nbarBuffer),length(nbarBuffer)+1);
    tArr0 = tArr0(1:end-1);
    dataArr = nbarBuffer;
    
    % === fit parameter guesses
    gammatot = 6e6; % x0(1)
    gammas = 5e5; % x0(2)
    deltab = 0.75; % x0(3)
    ni = dataArr(1); % x0(4)
    nf = mean(dataArr(end-10:end)); % x0(5)
    
    % pulse-on fitting function (PRX2015 S.I. for ref) with fast and slow bath turn-on
    fitFun = @(x,xdata) x(4)*exp(-x(1)*xdata) + x(5)*(1-exp(-x(1)*xdata)) + x(3)*x(5)*(x(1)/(x(2)-x(1)))*(exp(-x(2)*xdata) - exp(-x(1)*xdata));

    % initialize fit parameter guesses
    x0 = [gammatot, gammas, deltab, ni, nf];
    initialCurve = fitFun(x0, tArr0);
    
    % fitting
    [x, resnorm, resid, exitflag, output, lambda, J] = lsqcurvefit(fitFun,x0,tArr0,dataArr,[0, 0, 0, 0, 0]);
    
    % back-extrapolate fit curve by half a bin width to initial point
    offset = (0)*binsize; % how far to back-extrapolate fit from first "fully on" point
    plotdist = fliplr(-binsize:-binsize:-plotbacknum*binsize); % from true pulse start to first "fully on" point taken
    initialPoint = fitFun(x, offset);
    finalPoint = fitFun(x, max(tArr0));
       
    tArr = [plotdist tArr0];
    fitCurve = fitFun(x, tArr);
    
    % calculate error
    alpha = 0.1; % 90% confidence interval
    ci = nlparci(x,resid,'jacobian',J,'alpha',alpha);
    nimin = ci(4,1);
    nimax = ci(4,2);
    xparamsmin = [x(1), x(2), x(3), x(4)+nimin, x(5)];
    xparamsmax = [x(1), x(2), x(3), x(4)+nimax, x(5)];
    initialPtMin = fitFun(xparamsmin, offset);
    initialPtMax = fitFun(xparamsmax, offset);
    
    % plot fitting result
    figure();
    hold on;
    plot(tArr0,dataArr);
    plot(tArr,fitCurve,'r');
    hold off;
    xlabel('Time in pulse (s)');
    ylabel('n');
    close();
    
end


function badSets = filter3_reject_datasets(thresh);

endInfo = dir('filter3_DAQV_End_*.txt');
startInfo = dir('filter3_DAQV_Initial_*.txt');

% sort endInfo
NumArr = [];
for k = 1:length(endInfo)
    fn = endInfo(k).name;
    NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
end

indexArray = [NumArr', [1:length(endInfo)]'];
[values order] = sort(indexArray(:,1));

f3_end_voltagelog = []; f3_start_voltagelog = [];
for k = 1:length(endInfo)
    fn = endInfo(order(k)).name;
    f3_end_voltagelog = [f3_end_voltagelog load(endInfo(k).name)];
end

% sort startInfo
clear NumArr;
NumArr = [];
for k = 1:length(startInfo)
    fn = startInfo(k).name;
    NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
end

indexArray = [NumArr', [1:length(startInfo)]'];
[values order] = sort(indexArray(:,1));


for k = 1:length(startInfo)
    fn = startInfo(order(k)).name;
    f3_start_voltagelog = [f3_start_voltagelog load(startInfo(k).name)];
end

f3_end_voltagelog = f3_end_voltagelog(2:end);
f3_start_voltagelog = f3_start_voltagelog(1:end-1);


ds = f3_end_voltagelog./f3_start_voltagelog;

badSets = find(ds < thresh | ds > 1.5);
length(badSets);
%plot(ds); xlabel('file index'); ylabel('Filter 3 DAQ voltage');

end



function [Q] = estQcrude(ratio,Tper)

gamma = -log(ratio)/Tper;
Q = 2*pi*10e9/gamma;

end
