
% Top-level function for fitting pulse measurement data sets at varying
% n_c, pulse frequency, and rep rate.

function ds = plot_RFringup_sweepRFpow()

% INPUTS:
%   none
% OUTPUTS:
%   ds: data structure containing fit info. readout photon numbers,
%   background photon numbers, initial pulse count rates

bleed_through_CR_nc1 = 0;%3.9; % c.p.s., independently calibrated
%DCR = 2; % c.p.s., dark count rate67
%f_mechanical = 5.00905e9;
%kappa = 1.0429e9;
%gammaSB_factor = (kappa/(2*f_mechanical))^2;
%gammaSB_factor = 1;
%gammaSB0_redDetuned_nc100 = 2440; % photon count rate per phonon at red-detuned measurement power n_c = 100, independently calibrated on blue side
%gammaSB0_nc100 = gammaSB0_redDetuned_nc100*gammaSB_factor;
% Tag for data directories
% gammaSB0_nc39=gammaSB0est_noextinction_wEDFA(15.7);
gammaSB0_nc1=31.4;

S=9;

nameTag = ['RFringup_BothRedRFsweep' num2str(S) '*'];
%nameTag = ['red_probe_nc_bleedthu_noextinction_wEDFA_sweep' num2str(S) '*'];

% Name directory for saving fits
save_directory_prefix = ['plot_RFringup_sweep' num2str(S) '_plot_03032018'];

savedir_num = 0;
save_directory = [save_directory_prefix '_' num2str(savedir_num)];
while (exist(save_directory,'dir')==7)
    savedir_num = savedir_num + 1;
    save_directory = [save_directory_prefix '_' num2str(savedir_num)];
end
mkdir(save_directory);

dataPath = pwd;
saveFits = 1;
clear ds
format long

dirInfo = dir([nameTag]);

ds.lambdas = [];
ds.CRs = [];
ds.DCRs = [];
ds.relErrs = [];
ds.L1atten = [];
ds.L2atten = [];
ds.RFpow = [];
ds.occs=[];
ds.photonNumbers=[];
ds.T1pulse=[];

% check that each is a directory, then go into that directory
j = 0;
for k = 1:length(dirInfo)
    
    if dirInfo(k).isdir
        j = j + 1;
        dirName = dirInfo(k).name;
        %pulseFreq = sscanf(dirName(strfind(dirName,'pulse'):end),'pulse%fHz%*s');
        L1atten = sscanf(dirName(strfind(dirName,['L1att_']):end),['L1att_%fdB*s']);
        L2atten = sscanf(dirName(strfind(dirName,['L2att_']):end),['L2att_%fdB*s']);
        lambda = sscanf(dirName(strfind(dirName,'L2wvl_'):end),'L2wvl_%fnm*s');

        pulseFreq = sscanf(dirName(strfind(dirName,'PulseF_'):end),'PulseF_%fHz*s');
        RFpow = sscanf(dirName(strfind(dirName,'RFpow_'):end),'RFpow_%dBm*s');
        
        T1pulse = sscanf(dirName(strfind(dirName,'T1pulse_'):end),'T1pulse_%us*s');
       
        % go into that folder
        cd([dataPath '\' dirInfo(j).name]);

        % determine number of chunks
        datInfo = dir('PHcounts*.mat');
        numChunks = length(datInfo);

        if ~isempty(datInfo)
            fn1 = datInfo(1).name;
            intTime = sscanf(fn1(strfind(fn1,'intTime_'):end),'intTime_%fsec%*s');

            % combine data chunks
            cd(dataPath);
            [CR countsArr DCR] = combine_ph_datasets_CW(dataPath, dirName, numChunks, intTime, pulseFreq, lambda, saveFits, save_directory);
            %goodFit = input('Good? (y/n)','s');
            goodFit = 'y';
            if (strcmp(goodFit,'y'))
                
                ds.lambdas(end+1) = lambda;
                ds.L1atten(end+1) = L1atten;
                ds.L2atten(end+1) = L2atten;
                ds.RFpow(end+1) = RFpow;
                ds.T1pulse(end+1) = T1pulse;
                ds.DCRs(end+1) = DCR;
                ds.photonNumbers(end+1) = att2nc_arc(L2atten);
                ds.CRs(end+1) = CR - bleed_through_CR_nc1*ds.photonNumbers(end);
                ds.occs(end+1) = ds.CRs(end)/(gammaSB0_nc1*ds.photonNumbers(end));
            end

            %cd([dataPath '\' save_directory]);
            %save(['counts_' num2str(pulseFreq) 'Hz_rep_' num2str(atten) 'dB.mat'],'countsArr');
            cd(dataPath);
            %close;

            end
    end
end

cd([dataPath '\' save_directory]);
save('dataInfo.mat','ds');
cd(dataPath);

% 
% scatter(ds.photonNumbers,ds.CRs,'bo','MarkerEdgeColor','k','MarkerFaceColor','b'); 
% set(gca,'yscale','log');
% set(gca,'xscale','log');
% xlabel('n_c'); ylabel('Count Rate (c.p.s.)');
% title('count rate');
% grid on
% 
% hold off;
% cd([dataPath '\' save_directory]);
% saveas(gcf,['CR_power_sweep.fig']);

figure();
hold on;

uniqueT1pulse = unique(ds.T1pulse);
for q = 1:length(uniqueT1pulse)
    wvl = uniqueT1pulse(q);
    this_wvl_indices = find(ds.T1pulse==uniqueT1pulse(q));
    legendInfo{q} = ['\T1pulse = ' num2str(wvl) ' um'];
    %scatter(ds.photonNumbers,ds.occs,'go','MarkerEdgeColor','k','MarkerFaceColor','b'); 
%     scatter(ds.photonNumbers(this_wvl_indices),ds.occs(this_wvl_indices),'Filled');
scatter(ds.RFpow(this_wvl_indices),ds.occs(this_wvl_indices),'Filled');

end
hold off


set(gca,'yscale','lin');
set(gca,'xscale','lin');
xlabel('Rfpow'); ylabel('\langle n \rangle');
title('RF ringup RF power sweep');
legend(legendInfo)
grid on
box on

%hold off;
cd([dataPath '\' save_directory]);
saveas(gcf,['RFpow_sweep.fig']);


clear CRArr;
cd(dataPath);

end
%% END %%


%%%%% HELPER FUNCTIONS %%%%%
function [CR countsArr DCR] = combine_ph_datasets_CW(topDirectory,dataDirectory,N,Tint,f_pulse,lambda,saveFits,saveDir)

    DCR=16+12; % taken from 60 dB data
    Tper = 1/f_pulse;
    numChannels = 65536;
    postbin = 50;
    %pb_shift = 18; 
    pb_shift = 0;
    allCounts = zeros(numChannels, N);
    tbin = 0.512*(1:numChannels);
    thresh = 0.90;
    cd(dataDirectory);
    
    badSets = filter3_reject_datasets(thresh);

    numGoodSets = 0;
    for k = 1:N
        if ~ismember(k,badSets)
            numGoodSets = numGoodSets + 1;
            filename = sprintf(['PHcounts_intTime_' num2str(Tint) 'sec_fileNum%i_segment_1.mat'], k);
            allCounts(:,k) = importdata(filename);
        end
    end
  
    totCounts = sum(allCounts, 2);
    
    if postbin > 1
        pb_counts = [];
        pb_t = [];
        for k = 1:(length(totCounts)/postbin)
            pb_counts(end+1) = sum(totCounts((k-1)*postbin+1+pb_shift:k*postbin+pb_shift));
            pb_t(end+1) = 512e-12*(k-1)*postbin + 512e-12*pb_shift;
        end
    end

    countsArr = pb_counts.*Tper/(512e-12*postbin*Tint*numGoodSets);
    startBin = 1;
    endBin = round(length(countsArr)*(20/33.51));
    DCRstartBin = round(length(countsArr)*(20/33.51));
    DCRendBin = round(length(countsArr));
    DCR = mean(countsArr(DCRstartBin:DCRendBin));
    CR = mean(countsArr(startBin:endBin)) - DCR;
    cd(topDirectory);
    
    %plot(tbin/1e3, totCounts.*Tper/(512e-12*Tint*numGoodSets),'g');
    %hold on;

    plot(pb_t/1e-6,countsArr,'.-b')
    xlim([0 35])
    xlabel('time (\mus)')
    ylabel('count rate (Hz)')
    legend([num2str(0.512*postbin) 'ns bin'])
    hold off;

    % figure();
    % semilogy(pb_t/1e-6,countsArr,'.-b')
    % xlim([0 35])
    % xlabel('time (\mus)')
    % ylabel('count rate (Hz)')
    % legend([num2str(0.512*postbin) 'ns bin'])

    % identify starting point, end point

    % edges = edge(countsArr);
    % 
    % [val edge_bins] = find(edges);
    % startBin = edge_bins(1); endBin = edge_bins(end)-2;
    % 
    % disp('Using edge detection')
    
    relErr = 1/sqrt(sum(pb_counts));
    
%     semilogy(pb_t,countsArr);
%     xlabel('Time (s)'); ylabel('Count rate (c.p.s.)');
%     title(['Red side, Tper ' num2str(1000/f_pulse) ' ms']);

    %atten = sscanf(dataDirectory(strfind(dataDirectory,'sweep_'):end),'sweep_%fdB*s');
    if saveFits
        cd([topDirectory '\' saveDir]);
        saveas(gcf,['CountsArray_L2wvl' num2str(lambda) 'nm_pulsing.fig']);
        save(['countsArr_onResonance_CW_WL' num2str(lambda) 'pm_pulsing.mat'],'countsArr');
        cd(topDirectory);
    end


end

% ---

function badSets = filter3_reject_datasets(thresh);

    endInfo = dir('filter3_DAQV_End_*.txt');
    startInfo = dir('filter3_DAQV_Initial_*.txt');

    % sort endInfo
    NumArr = [];
    for k = 1:length(endInfo)
        fn = endInfo(k).name;
        NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
    end

    indexArray = [NumArr', [1:length(endInfo)]'];
    [values order] = sort(indexArray(:,1));

    f3_end_voltagelog = []; f3_start_voltagelog = [];
    for k = 1:length(endInfo)
        fn = endInfo(order(k)).name;
        f3_end_voltagelog = [f3_end_voltagelog load(endInfo(k).name)];
    end

    % sort startInfo
    clear NumArr;
    NumArr = [];
    for k = 1:length(startInfo)
        fn = startInfo(k).name;
        NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
    end

    indexArray = [NumArr', [1:length(startInfo)]'];
    [values order] = sort(indexArray(:,1));


    for k = 1:length(startInfo)
        fn = startInfo(order(k)).name;
        f3_start_voltagelog = [f3_start_voltagelog load(startInfo(k).name)];
    end

    f3_end_voltagelog = f3_end_voltagelog(2:end);
    f3_start_voltagelog = f3_start_voltagelog(1:end-1);


    ds = f3_end_voltagelog./f3_start_voltagelog;

    badSets = find(ds < thresh | ds > 1.5);
    length(badSets);
    %plot(ds); xlabel('file index'); ylabel('Filter 3 DAQ voltage');

end
