% Solve driven damped ODE for phonon amplitude
% Drive tone consists of red-detuned pump with intracavity photon number nc0, modulated sideband with
% on-cavity-resonance photon number nc1

% physical constants
hbar = 6.626e-34;
c=299792458;

% -------------- Calculate pump powers -----------------

% RF drive power is in dBm
% modulator Vpi
Vpi = 4.1;
RFdrivePower = 0;
atten = 8; % dB

lambda0 = 1538.9708e-9;
etaKappa = 0.228;
etaCpl = 0.362;
Qt=339e3;
Pin_0dB = 0.405e-6;
Pin_0dB_sb1 = Pin_0dB*besselj(1,sqrt(50*(0.001*10^(RFdrivePower/10)))*pi/Vpi)^2;

omegao = 2*pi*c/lambda0;
f0 = omegao/2/pi;
eta12 = 0.867;
eta = eta12*etaCpl;
kappa=f0/Qt;
kappaE = etaKappa*kappa;
hbar = 1.0545718e-34;

Pin0 = eta*Pin_0dB*10^(-(atten)/10); % red-detuned carrier
Pin1 = eta*Pin_0dB_sb1*10^(-(atten)/10); % on-resonance sideband

n0 = 5; % [phonons] initial mechanical occupancy before drive pulse
meff = 300e-18; % 300 fg, expressed in kg
fm = 5.312439893e9; % [Hz] mechanical frequency
omegaM = 2*pi*fm; % [rad Hz] mechanical angular frequency
xzpf = sqrt(hbar/(2*meff*omegaM)); % few fm
x0 = xzpf*sqrt(2*n0); % [m] initial mechanical displacement


nc0 = (Pin0*eta/(hbar*omegao))*(2*pi*kappaE/((2*pi*fm)^2 + (0.5*2*pi*kappa)^2));
nc1 = (Pin1*eta/(hbar*omegao))*(2*pi*kappaE/((0.5*2*pi*kappa)^2));
% -------------------------------------------------------------------------

gammaOM_nc1 = 2*pi*3.9e3; % [rad Hz] back-action damping rate (+) for red-detuned
gammaP_nc1 = 2*pi*1.4e3;
gammai = 2*pi*1;
gammaT = nc0*gammaOM_nc1 + gammaP_nc1*(nc0+nc1).^(2/3) + gammai;
g = 2*pi*800e3; % [rad Hz] optomechanical coupling 

fudge=1;
A = fudge*(1/meff)*(1/xzpf)*(g/omegao^2); 
F0 = A*sqrt(Pin0*Pin1); % beat-note driving tone amplitude
Fstatic = A*(Pin0 + Pin1); % static force term

% solve using ODE45
tspan = [0 10e-6];
N = 1e6;
dt = tspan(end)/(N-1);
tArr = linspace(tspan(1), tspan(2), N);

alpha0 = zeros(N,1);
alpha0(1,1) = sqrt(nc0);
alphain0 = sqrt(100*nc0);

beta0 = zeros(N,1);
beta0(1,1) = sqrt(n0);

DET = +1; % +1 for red-detuned
Delta = omegaM;

for n = 1:N-1
   alpha0(n+1,1) = alpha0(n,1) + dt * (-(1i*0*Delta + 2*pi*kappa/2)*alpha0(n,1) - 1i*g*alpha0(n,1)*(beta0(n,1) + conj(beta0(n,1))) + sqrt(2*pi*kappaE)*alphain0);
   beta0(n+1,1) = beta0(n,1) + dt * (-(1i*0*omegaM + gammaT/2)*beta0(n,1) - 1i*g*abs(alpha0(n+1,1))^2);
end

nbar = abs(beta0(:,1)).^2;
semilogy(tArr/1e-6, nbar);
xlabel('Time (\mus)'); ylabel('\langlen\rangle');
box on;



