
% Top-level function for fitting pulse measurement data sets at varying
% n_c, pulse frequency, and rep rate.

function GAMMA = plot_RFringup_L2ringup_sweepToff_CI()

% INPUTS:
%   none
% OUTPUTS:
%   ds: data structure containing fit info. readout photon numbers,
%   background photon numbers, initial pulse count rates

bleed_through_CR_nc1 = 0;%3.9; % c.p.s., independently calibrated
%DCR = 2; % c.p.s., dark count rate67
fm_nominal = 5.312439893e9;
%kappa = 1.0429e9;
%gammaSB_factor = (kappa/(2*f_mechanical))^2;
%gammaSB_factor = 1;
%gammaSB0_redDetuned_nc100 = 2440; % photon count rate per phonon at red-detuned measurement power n_c = 100, independently calibrated on blue side
%gammaSB0_nc100 = gammaSB0_redDetuned_nc100*gammaSB_factor;
% Tag for data directories
% gammaSB0_nc39=gammaSB0est_noextinction_wEDFA(15.7);
gammaSB0_nc1=31.4;
correctionForLargeL1pow= 1; %use to correct for L1 generated gammaOM, but can not use this here since L1 only cools it to CR of 500.

S = 1;

nameTag = ['MultPulse_RFToff_megasweep' num2str(S) '*'];
%nameTag = ['red_probe_nc_bleedthu_noextinction_wEDFA_sweep' num2str(S) '*'];

% Name directory for saving fits
save_directory_prefix = ['plot_RFToff_sweep' num2str(S) '_plot_07032018_CI'];

savedir_num = 0;
save_directory = [save_directory_prefix '_' num2str(savedir_num)];
while (exist(save_directory,'dir')==7)
    savedir_num = savedir_num + 1;
    save_directory = [save_directory_prefix '_' num2str(savedir_num)];
end
mkdir(save_directory);

dataPath = pwd;
saveFits = 1;
clear ds
format long

dirInfo = dir([nameTag]);

ds.lambdas = [];
ds.CRs = [];
ds.DCRs = [];
ds.relErrs = [];
ds.L1atten = [];
ds.L2atten = [];
ds.RFpow = [];
ds.occs=[];
ds.photonNumbers1=[];
ds.photonNumbers2=[];
ds.T1pulse=[];
ds.T2pulse=[];
ds.Twait = [];
ds.Fm = [];
ds.Toffs = [];

% check that each is a directory, then go into that directory
j = 0;
for k = 1:length(dirInfo)
    
    if dirInfo(k).isdir
        j = j + 1;
        dirName = dirInfo(k).name;
        %pulseFreq = sscanf(dirName(strfind(dirName,'pulse'):end),'pulse%fHz%*s');
        L1atten = sscanf(dirName(strfind(dirName,['L1att_']):end),['L1att_%fdB*s']);
        L2atten = sscanf(dirName(strfind(dirName,['L2att_']):end),['L2att_%fdB*s']);
%         lambda = sscanf(dirName(strfind(dirName,'L2wvl_'):end),'L2wvl_%fnm*s');
        lambda = 1539.0135;

        pulseFreq = sscanf(dirName(strfind(dirName,'PulseF_'):end),'PulseF_%fHz*s');
        RFpow = sscanf(dirName(strfind(dirName,'RF_'):end),'RF_%dBm*s');
        
        T1pulse = sscanf(dirName(strfind(dirName,'T1pul_'):end),'T1pul_%f*s');
        T2pulse = sscanf(dirName(strfind(dirName,'T2pul_'):end),'T2pul_%f*s');
        
        dirnametoff = dirName(20:end);
        Toff = 1e-6*sscanf(dirnametoff(strfind(dirnametoff,'Toff_'):end),'Toff_%f*s'); % put it into seconds
        %Twait = sscanf(dirName(strfind(dirName,'maxToff_'):end),'maxToff_%f*s');
       
        % go into that folder
        cd([dataPath '\' dirInfo(j).name]);

        % determine number of chunks
        datInfo = dir('PHcounts*.mat');
        numChunks = length(datInfo);

        if ~isempty(datInfo)
            fn1 = datInfo(1).name;
            intTime = sscanf(fn1(strfind(fn1,'intTime_'):end),'intTime_%fsec%*s');

            % combine data chunks
            cd(dataPath);
            [CR countsArr DCR] = combine_ph_datasets_CW(dataPath, dirName, numChunks, intTime, pulseFreq, lambda, saveFits, save_directory);
            %goodFit = input('Good? (y/n)','s');
            goodFit = 'y';
            if (strcmp(goodFit,'y'))
                
                ds.lambdas(end+1) = lambda;
                ds.L1atten(end+1) = L1atten;
                ds.L2atten(end+1) = L2atten;
                ds.RFpow(end+1) = RFpow;
                ds.T1pulse(end+1) = T1pulse;
                ds.T2pulse(end+1) = T2pulse;
                ds.Toffs(end+1) = Toff;
                
                %ds.Twait(end+1) = Twait;
                ds.DCRs(end+1) = DCR;
                ds.photonNumbers1(end+1) = att2nc(L1atten);
                ds.photonNumbers2(end+1) = att2nc_arc(L2atten);
                ds.CRs(end+1) = correctionForLargeL1pow*(CR - bleed_through_CR_nc1*ds.photonNumbers1(end));
                ds.occs(end+1) = ds.CRs(end)/(gammaSB0_nc1*ds.photonNumbers1(end));
            end

            %cd([dataPath '\' save_directory]);
            %save(['counts_' num2str(pulseFreq) 'Hz_rep_' num2str(atten) 'dB.mat'],'countsArr');
            cd(dataPath);
            %close;

            end
    end
end

cd([dataPath '\' save_directory]);
save('dataInfo.mat','ds');
cd(dataPath);

% 
% scatter(ds.photonNumbers,ds.CRs,'bo','MarkerEdgeColor','k','MarkerFaceColor','b'); 
% set(gca,'yscale','log');
% set(gca,'xscale','log');
% xlabel('n_c'); ylabel('Count Rate (c.p.s.)');
% title('count rate');
% grid on
% 
% hold off;
% cd([dataPath '\' save_directory]);
% saveas(gcf,['CR_power_sweep.fig']);

uniqueToffs = unique(ds.Toffs);

ToffsArr = [];
nbars = [];
nbarErrs = [];

for q = 1:length(uniqueToffs)
    thisToff = uniqueToffs(q);
    
    thisToffindices = find(ds.Toffs==thisToff);
    ToffsArr(q) = thisToff;
    
    nbardat = ds.occs(thisToffindices); % [phonons]
    nbars(q) = mean(nbardat);
    nbarErrs(q) = std(nbardat);
    
end


figure();
hold on;
errorbar(ToffsArr,nbars,nbarErrs,'o','MarkerFaceColor','b','MarkerEdgeColor','b');
xlabel('T_{off} (s)'); ylabel('\langlen\rangle');
box on

Toffs = ToffsArr;
nbar = nbars/max(nbars);



% get region to fit
[ToffBds CRbds] = ginput(2);
%find Toff values and nRatios in range
ToffBds = ToffBds;
fitIndices = find(Toffs>min(ToffBds) & Toffs<max(ToffBds));
fitToffs = Toffs(fitIndices);
Toff_offset = 0%min(fitToffs);
fitToffs = fitToffs - Toff_offset;
fitnRatios = nbar(fitIndices);

tArr = [0 logspace(log10(0.5*min(Toffs(fitIndices))),log10(max(Toffs(fitIndices))),1e4)];%[0 logspace(log10(0.9*min(Toffs(fitIndices))),log10(max(Toffs(fitIndices))),1e4)];



% === DECAYS TO A CONSTANT OFFSET VALUE ===================================
%     GammaFitCurve = @(x,fitToffs)(x(2) + x(3)*exp(-x(1)*fitToffs));
%     gammaGuess = 1/(max(fitToffs) - min(fitToffs));
%     x0 = [gammaGuess min(fitnRatios) max(fitnRatios)];
% 
%     initialCurve = (x0(2) + x0(3)*exp(-x0(1)*tArr));
%     fitParams = lsqcurvefit(GammaFitCurve,x0,fitToffs,fitnRatios,[0 0 0],[1e6 50 100]);
%     gammaTotal_in_radians = fitParams(1);
%     Q_final = f_mechanical/(gammaTotal_in_radians/2/pi);
%     fitCurve = GammaFitCurve(fitParams, tArr);
%%%% ======================================================================

%%%% === DECAYS TO A CONSTANT OFFSET VALUE logfit===================================
    GammaFitCurve = @(x,fitToffs)(log10((x(2) + x(3)*exp(-x(1)*fitToffs))));
    gammaGuess = 4/(max(fitToffs) - min(fitToffs));
    x0 = [gammaGuess 6.2/max(nbars) max(fitnRatios)];

    initialCurve = log10((x0(2) + x0(3)*exp(-x0(1)*fitToffs)));
    [fitParams, resnorm, resid, exitflag, output, lambda, J]  = lsqcurvefit(GammaFitCurve,x0,fitToffs,log10(fitnRatios),[0 6.2/max(nbars) 0],[1e6 6.2/max(nbars) 100]);
    gammaTotal_in_radians = fitParams(1);
    alpha = 0.1;
    ci = nlparci(fitParams, resid, 'jacobian',J,'alpha',alpha);
    gammaLower = ci(1,1)/(2*pi);
    gammaUpper = ci(1,2)/(2*pi);
    gammaEst = gammaTotal_in_radians/(2*pi);
    GAMMA = [gammaLower, gammaEst, gammaUpper];
    Q_final = fm_nominal/(gammaTotal_in_radians/2/pi);
    fitCurve = 10.^GammaFitCurve(fitParams, tArr);
    
%%% ======================================================================

% 
% % === DECAYS TO ZERO ======================================================
% GammaFitCurve = @(x,fitToffs)(x(2)*exp(-x(1)*fitToffs));
% gammaGuess = 1/(max(fitToffs) - min(fitToffs));
% x0 = [gammaGuess max(fitnRatios)];
% 
% initialCurve = (x0(2)*exp(-x0(1)*tArr));
% fitParams = lsqcurvefit(GammaFitCurve,x0,fitToffs,fitnRatios,[0 0],[1e6 100]);
% gammaTotal_in_radians = fitParams(1);
% Q_final = fm_nominal/(gammaTotal_in_radians/2/pi);
% fitCurve = GammaFitCurve(fitParams, tArr);
% % =========================================================================



hold on
plot(tArr+Toff_offset,fitCurve*max(nbars),'r','LineWidth',2);
set(gca,'YScale','log');

title(['Ringdown curve | Fitted Q = ' num2str(Q_final/1e9) '\times 10^9']);
hold off
saveas(gcf,['Fitted_gamma_' round(num2str(gammaTotal_in_radians/2/pi)) 'Hz.fig']);

%     figure();
%     scatter(ds.Toffs,ds.gammatotal);
%     ylabel('gammaTotal (radHz)'); xlabel('Toff');
%     saveas(gcf,'gammaTotalFitted.fig');
%     
%     figure();
%     scatter(ds.Toffs,ds.gammaS);
%     ylabel('gammaS (radHz)'); xlabel('Toff');
%     saveas(gcf,'gammaSFitted.fig');
%     
%     figure();
%     scatter(ds.Toffs,ds.deltab);
%     ylabel('SBF'); xlabel('Toff');
%     saveas(gcf,'deltabFitted');


saveas(gcf,['nbar_Toffsweep.fig']);

hold off

clear CRArr;
cd(dataPath);

end
%% END %%


%%%%% HELPER FUNCTIONS %%%%%
function [CR countsArr DCR] = combine_ph_datasets_CW(topDirectory,dataDirectory,N,Tint,f_pulse,lambda,saveFits,saveDir)

    DCR=2.15; % taken from 60 dB data
    Tper = 1/f_pulse;
    numChannels = 65536;
    postbin = 50;
    %pb_shift = 18; 
    pb_shift = 0;
    allCounts = zeros(numChannels, N);
    tbin = 0.512*(1:numChannels);
    thresh = 0.90;
    cd(dataDirectory);
    
    badSets = filter3_reject_datasets(thresh);

    numGoodSets = 0;
    for k = 1:N
        if ~ismember(k,badSets)
            numGoodSets = numGoodSets + 1;
            filename = sprintf(['PHcounts_intTime_' num2str(Tint) 'sec_fileNum%i_segment_1.mat'], k);
            allCounts(:,k) = importdata(filename);
        end
    end
  
    totCounts = sum(allCounts, 2);
    
    if postbin > 1
        pb_counts = [];
        pb_t = [];
        for k = 1:(length(totCounts)/postbin)
            pb_counts(end+1) = sum(totCounts((k-1)*postbin+1+pb_shift:k*postbin+pb_shift));
            pb_t(end+1) = 512e-12*(k-1)*postbin + 512e-12*pb_shift;
        end
    end

    countsArr = pb_counts.*Tper/(512e-12*postbin*Tint*numGoodSets);
    startBin = 1;
    endBin = round(length(countsArr)*(33.51/33.51));
    DCRstartBin = round(length(countsArr)*(30/33.51));
    DCRendBin = round(length(countsArr));
%     DCR = mean(countsArr(DCRstartBin:DCRendBin));
    CR = mean(countsArr(startBin:endBin)) - DCR;
    cd(topDirectory);
    
    %plot(tbin/1e3, totCounts.*Tper/(512e-12*Tint*numGoodSets),'g');
    %hold on;

%     plot(pb_t/1e-6,countsArr,'.-b')
%     xlim([0 35])
%     xlabel('time (\mus)')
%     ylabel('count rate (Hz)')
%     legend([num2str(0.512*postbin) 'ns bin'])
%     hold off;

    % figure();
    % semilogy(pb_t/1e-6,countsArr,'.-b')
    % xlim([0 35])
    % xlabel('time (\mus)')
    % ylabel('count rate (Hz)')
    % legend([num2str(0.512*postbin) 'ns bin'])

    % identify starting point, end point

    % edges = edge(countsArr);
    % 
    % [val edge_bins] = find(edges);
    % startBin = edge_bins(1); endBin = edge_bins(end)-2;
    % 
    % disp('Using edge detection')
    
    relErr = 1/sqrt(sum(pb_counts));
    
%     semilogy(pb_t,countsArr);
%     xlabel('Time (s)'); ylabel('Count rate (c.p.s.)');
%     title(['Red side, Tper ' num2str(1000/f_pulse) ' ms']);

    %atten = sscanf(dataDirectory(strfind(dataDirectory,'sweep_'):end),'sweep_%fdB*s');
%     if saveFits
%         cd([topDirectory '\' saveDir]);
%         saveas(gcf,['CountsArray_L2wvl' num2str(lambda) 'nm_pulsing.fig']);
%         save(['countsArr_onResonance_CW_WL' num2str(lambda) 'pm_pulsing.mat'],'countsArr');
%         cd(topDirectory);
%     end


end

% ---

function badSets = filter3_reject_datasets(thresh);

    endInfo = dir('filter3_DAQV_End_*.txt');
    startInfo = dir('filter3_DAQV_Initial_*.txt');

    % sort endInfo
    NumArr = [];
    for k = 1:length(endInfo)
        fn = endInfo(k).name;
        NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
    end

    indexArray = [NumArr', [1:length(endInfo)]'];
    [values order] = sort(indexArray(:,1));

    f3_end_voltagelog = []; f3_start_voltagelog = [];
    for k = 1:length(endInfo)
        fn = endInfo(order(k)).name;
        f3_end_voltagelog = [f3_end_voltagelog load(endInfo(k).name)];
    end

    % sort startInfo
    clear NumArr;
    NumArr = [];
    for k = 1:length(startInfo)
        fn = startInfo(k).name;
        NumArr = [NumArr sscanf(fn(findstr(fn,'Num'):end),'Num%d_%*s')]; 
    end

    indexArray = [NumArr', [1:length(startInfo)]'];
    [values order] = sort(indexArray(:,1));


    for k = 1:length(startInfo)
        fn = startInfo(order(k)).name;
        f3_start_voltagelog = [f3_start_voltagelog load(startInfo(k).name)];
    end

    f3_end_voltagelog = f3_end_voltagelog(2:end);
    f3_start_voltagelog = f3_start_voltagelog(1:end-1);


    ds = f3_end_voltagelog./f3_start_voltagelog;

    badSets = find(ds < thresh | ds > 1.5);
    length(badSets);
    %plot(ds); xlabel('file index'); ylabel('Filter 3 DAQ voltage');

end
