
fm_nominal = 5.312439893e9;

pp = load('temp_sweep_mechdata.mat');
P = pp.mechdat;
P(P==0) = NaN;
Tf = P(:,1)/1e3;

mechf1 = fm_nominal + P(:,2)*1e3; % (Hz) Note, freq offset data is in kHz
deltaf1 = (mechf1(:) - mechf1(1))/1e3; % (kHz) offset from value at base temperature

mechf2 = fm_nominal + P(:,7)*1e3; % (Hz) Note, freq offset data is in kHz
deltaf2 = (mechf2(:) - mechf1(1))/1e3; % (kHz) offset from value at base temperature

mechf3 = fm_nominal + P(:,11)*1e3; % (Hz) Note, freq offset data is in kHz
deltaf3 = (mechf3(:) - mechf1(1))/1e3; % (kHz) offset from value at base temperature


mechf4 = fm_nominal + P(:,14)*1e3; % (Hz) Note, freq offset data is in kHz
deltaf4 = (mechf4(:) - mechf1(1))/1e3; % (kHz) offset from value at base temperature


% === Fit decay constant to model
% For now, use simple power law scaling

% looks like a transition point occurs at Tf = 150 mK
g0dat = [P(:,4); P(:,9); P(:,13)];
blanks = isnan(g0dat);
Tfdat = Tf;
Tfdat(blanks) = NaN;

Tc = 175e-3;

pp1 = lsqcurvefit(@(x,xdata) x(1)*xdata.^(x(2)), [1e-2, 1], Tfdat(Tfdat<=Tc), g0dat(Tfdat<=Tc));
pp2 = lsqcurvefit(@(x,xdata) x(1)*xdata.^(x(2)), [1e-5, 3], Tfdat(Tfdat>=Tc), g0dat(Tfdat>=Tc));
Tfplot = logspace(-3,0,100);
curve1 = pp1(1)*Tfplot.^pp1(2);
curve2 = pp2(1)*Tfplot.^pp2(2)
% ---------



figure();
hold on
scatter(Tf, deltaf1, 'Filled','b');
scatter(Tf, deltaf2, 'Filled','r');
scatter(Tf, deltaf3, 'Filled','k');
hold off
xlabel('T_{fridge} (K)'); ylabel('\deltaf (kHz)');
box on
saveas(gcf,'Tsweep_frequency.fig');




figure();
hold on
scatter(Tf, P(:,3), 'Filled','b');
scatter(Tf, P(:,8), 'Filled','r');
scatter(Tf, P(:,12), 'Filled','k');
hold off
xlabel('T_{fridge} (K)'); ylabel('Linewidth (kHz)');
box on
saveas(gcf,'Tsweep_linewidth.fig');




figure();
hold on
scatter(Tf, P(:,4), 'Filled','b');
scatter(Tf, P(:,9), 'Filled','r');
scatter(Tf, P(:,13), 'Filled','k');
plot(Tfplot, curve1, 'r');
plot(Tfplot, curve2, 'g');
plot(Tfplot, curve1+curve2, 'k-');
hold off
set(gca,'XScale','log');
set(gca,'YScale','log');
xlabel('T_{fridge} (K)'); ylabel('Decay constant \gamma_0/2\pi (Hz)');
title(['power laws: (' num2str(pp1(2)) ', ' num2str(pp2(2)) ')']);
box on
saveas(gcf,'Tsweep_gamma0.fig');













