% Matlab script to plot Bose factor
% 
% Written by Oskar Painter, 8.25.2017


close all;
clear all;
format long;

c=3e8; % speed of light in m/s
hbar=6.626e-34/2/pi; % quantum unit (J s)
kB=1.3806488e-23; % Boltzmann constant (J/K)
eps_o=8.85e-12; % permitiivity of free-space (F/m)
q_e = 1.602e-19; % magnitude of charge of an electron (C)
n_Si=3.45; % refractive index of Si
n_SiNx=2; % refractive index of SiNx
n_eff=2.8; % effective index of WGM modes (TM)
m_o = 9.1095e-31; % mass of a bare electron (kg)
m_ch = 0.39*m_o; % conductive effective hole mass (kg)
m_ce = 0.26*m_o; % conductive effective hole mass (kg)
mu_h = 410e-4; % hole mobility in m^2/V/s (good for N_A <= 10^16 cm^-3)
mu_e = 1300e-4; % electron mobility in m^2/V/s (good for N_D <= 10^16 cm^-3)

omega_m = 2*pi*5.31e9; % mechanical mode frequency (rad/s)

Tb=logspace(-2,1,1e4);

%myfn = @(Tf,dTb,Gth,Pth) dtemp-power./(gthermal.*(temp+dtemp).^3); % parametrized offset function

Gth=(Tb).^(2)./(32500); % thermal conductance (W/K) --> post-factor yields offset in mK at 10mK fridge temperature
Pth=1e-9; % heating power (W)
dTb=Pth./Gth; % temperature offset of sample (K)
%dTb=50e-3; %

Tf=Tb-dTb; % corresponding fridge temperature (K)

vsound = 10e3; % sound velocity in Si (m/s)
lcritical = 0.17e-6; % critical dimension of structure (width) in (m)
omegacutoff = 2*pi*(vsound./lcritical); % cut-off frequency for 2D to 1D DOS transition in cavity structure (rad/s)
Tc = hbar.*omegacutoff/kB; % cutoff temperature (K)

a = 1; % power law for 3 phonon scattering in cavity structure (3D = 4, 2D = 3, 1D = 2)
gamma3phononest=(2.5e3).*Tb.*exp(-hbar.*omegacutoff./(kB.*Tb))./(1-exp(-hbar.*omegacutoff./(kB.*Tb))).^a; % 3-phonon scattering 
gammanonresbulkTLSest=(3.3).*Tb.^1; % non-resonant bulk Si TLS damping rate (Hz)


Tfdata=1e-3*[7.10000000000000,	20.7000000000000,	41.4000000000000,	58.1000000000000,	82.2000000000000,	101,	90.5000000000000,	150.100000000000,	200.500000000000,	150,	200,	175,	199.500000000000,	250	,300,	350, 400, 450, 500, 595]; % measured fridge temperature (K)
gammadata=[0.106850000000000,	0.212900000000000,	0.369000000000000,	0.718680000000000	0.574250000000000,	1.00100000000000,	0.616000000000000,	1.40860000000000,	4.92350000000000,	1.59200000000000,	4.13450000000000,	3.50000000000000,	4.49000000000000,	6.35080000000000,	12.6020000000000,	32.1895000000000, 22.65, 43.13, 41.04, 52.93]; % measured mechanical damping (Hz)

Tbdata=Tfdata;

for m=1:length(Tfdata);
    [val,index]=min(abs(Tf-Tfdata(m)));
    Tbdata(m)=Tbdata(m)+dTb(index);
end

% 
% % fit for gammanonresbulkTLS coefficient
% dataInd2D = find(gammadata<2); % select linear portion of data (Hz)
% gamma2Ddata = gammadata(dataInd2D);
% Tbdata2D = Tbdata(dataInd2D);
% P2D = lsqcurvefit(@(x,xdata)x(1)*xdata, [2.7, 0], Tbdata2D, gamma2Ddata);
% gammanonresbulkTLS = P2D(1).*Tb.^1;
% 
% % fit for gamma3phonon coefficient
% dataInd3phonon = find(gammadata>2); %
% gamma3phonondata = gammadata(dataInd3phonon);
% Tbdata3phonon = Tbdata(dataInd3phonon);
% errfunc = @(xx) sum((gamma3phononFunc(xx,omegacutoff,Tbdata3phonon) - gamma3phonondata).^2);
% options = optimset('PlotFcns',@optimplotfval,'MaxIter',15);
% P3D = fminsearch(errfunc, [2.5e3], options);
% %P3D = fminsearch(gamma3phononFunc(x,hbar,kB,omegacutoff,xdata),Tbdata3phonon, gamma3phonondata);
% gamma3phonon = gamma3phononFunc(P3D,omegacutoff,Tb);
% 
% 
% gammatot=gamma3phonon + gammanonresbulkTLS; % total mechanical damping rate (Hz)

figure;loglog(Tb,dTb,'r-');
xlabel('effective mode bath temp (K)');
ylabel('temp offset (K)');

figure;loglog(Tb,Tf,'r-');
xlabel('effective mode bath temp (K)');
ylabel('fridge temp (K)');


figure;scatter(Tbdata,gammadata,'Filled');
xlabel('effective mode bath temp (K)');
ylabel('\gamma_0/2\pi (Hz)');

% 
% figure;loglog(Tb,gamma3phonon,'r-',Tb,gammanonresbulkTLS,'g-');
% xlabel('bath temp (K)');
% ylabel('mechanical damping rate (Hz)');
% legend('3-phonon','non-res bulk TLS','best');
% %axis([5e-3 1.4 0.06 1e2]);
% 
% figure;loglog(Tf,gammatot,'g-',Tfdata,gammadata,'rs','MarkerSize', 10);
% xlabel('fridge temp (K)');
% ylabel('mechanical damping rate (Hz)');
% axis([5e-3 1.4 0.06 1e2]);
% 
% figure();loglog(Tf,gammatot,'g-',Tfdata,gammadata,'rs','MarkerSize', 10);
% hold on
% plot(Tf,gamma3phonon);plot(Tf,gammanonresbulkTLS);
% xlabel('fridge temp (K)');
% ylabel('mechanical damping rate (Hz)');
% hold off
% 
% figure;loglog(Tb,gammatot,'b-',Tbdata,gammadata,'rs','MarkerSize', 10);
% xlabel('effective mode bath temp (K)');
% ylabel('mechanical damping rate (Hz)');
% %axis([5e-3 1.4 0.06 1e2]);
% 
% figure;loglog(Tb,gammatot,'b-')
% hold on
% plot(Tb,gamma3phonon);plot(Tb,gammanonresbulkTLS);
% errorbar(Tbdata,gammadata,gammaLdata,gammaUdata,'s','MarkerEdgeColor','r');
% xlabel('effective mode bath temp (K)');
% ylabel('mechanical damping rate (Hz)');
% hold off
% 
% 
% figure;loglog(Tf,gammatot,'b-')
% hold on
% plot(Tf,gamma3phonon);plot(Tf,gammanonresbulkTLS);
% errorbar(Tfdata,gammadata,gammaLdata,gammaUdata,'s','MarkerEdgeColor','r');
% xlabel('Tf (K)');
% ylabel('mechanical damping rate (Hz)');
% hold off