% Script to fit nbar data to nbar (on-state) model curve generated by OJP's
% mK script
% Greg MacCabe, 09/12/2017
% ===========================


% Load nbar minimum occupancy curve data
foo=load('nmindat.mat');
nmindat=foo.nmindat;
tpulsedata=nmindat(:,1)*1e-6; % (s)
nbardata=nmindat(:,2); % (phonon #)
pulseonpoint=10.84416e-6; % point at which optical pulse is initially turned on with EO modulators (s)
pulseoffpoint=20.81792e-6; % point at which optical pulse is initially turned off with EO modulators (s)
tbinsize=10.24e-9; % bin size (s)
tinit=(1)*tbinsize; % offset from when we turned pulse on to when we took first nbar point (s)

[vs,is]=min(abs(tpulsedata-pulseonpoint));
[ve,ie]=min(abs(tpulsedata-pulseoffpoint));

tondata=tpulsedata(is:ie)-pulseonpoint+tinit; % tinit is the point taken corresponding to n_i
nbartondata=nbardata(is:ie);

tondatafit=tondata(:); % only the early time bins are really influenced by this fit. Don't waste time weighting the later time bins.
nbartondatafit=nbartondata(:);

Tb_guess = 1; % times 30 mK
Acoeff_guess = 1.3;

errfunc = @(xx) sum((OMC_fitcurve_minocc(tondatafit, xx) - nbartondatafit).^2);
options = optimset('PlotFcns',@optimplotfval,'MaxIter',15);
pp = fminsearch(errfunc, [Tb_guess, Acoeff_guess], options);

[ton fittednbarton] = OMC_nbarton_eval(pp(1)*30e-3, pp(2));

disp(['Fitted T_b: ' num2str(30*pp(1)) ' mK']);
figure();
loglog(ton,fittednbarton,'r-',tondata,nbartondata,'bs')
xlabel('Time during pulse (s)');
ylabel('Occupancy n');